@@ -1,14 +1,14 @@
 """
 ldap - base module
 
-See http://python-ldap.sourceforge.net for details.
+See http://www.python-ldap.org/ for details.
 
-$Id: __init__.py,v 1.59 2008/05/02 13:39:02 stroeder Exp $
+$Id: __init__.py,v 1.64 2009/04/17 14:38:59 stroeder Exp $
 """
 
 # This is also the overall release version number
 
-__version__ = '2.3.5'
+__version__ = '2.3.8'
 
 import sys
 
@@ -46,10 +46,11 @@ _ldap_module_lock = LDAPLock()
 
 from functions import open,initialize,init,get_option,set_option
 
-from ldap.dn import explode_dn,explode_rdn
+from ldap.dn import explode_dn,explode_rdn,str2dn,dn2str
+del str2dn
+del dn2str
 
 # More constants
 
 # For compability of 2.3 and 2.4 OpenLDAP API
 OPT_DIAGNOSTIC_MESSAGE = OPT_ERROR_STRING
-
