@@ -1,10 +1,9 @@
 """
 ldap.async - handle async LDAP operations
-written by Michael Stroeder <michael@stroeder.com>
 
-See http://python-ldap.sourceforge.net for details.
+See http://www.python-ldap.org/ for details.
 
-\$Id: async.py,v 1.24 2005/11/07 11:43:00 stroeder Exp $
+\$Id: async.py,v 1.27 2009/04/17 14:34:34 stroeder Exp $
 
 Python compability note:
 Tested on Python 2.0+ but should run on Python 1.5.x.
@@ -193,10 +192,35 @@ class Dict(AsyncSearchHandler):
   def _processSingleResult(self,resultType,resultItem):
     if _entryResultTypes.has_key(resultType):
       # Search continuations are ignored
-      dn,entry = resultItem    
+      dn,entry = resultItem
       self.allEntries[dn] = entry
 
 
+class IndexedDict(Dict):
+  """
+  Class for collecting all search results into a dictionary {dn:entry}
+  and maintain case-sensitive equality indexes to entries
+  """
+
+  def __init__(self,l,indexed_attrs=None):
+    Dict.__init__(self,l)
+    self.indexed_attrs = indexed_attrs or tuple()
+    self.index = {}.fromkeys(self.indexed_attrs,{})
+
+  def _processSingleResult(self,resultType,resultItem):
+    if _entryResultTypes.has_key(resultType):
+      # Search continuations are ignored
+      dn,entry = resultItem
+      self.allEntries[dn] = entry
+      for a in self.indexed_attrs:
+	if entry.has_key(a):
+	  for v in entry[a]:
+	    try:
+    	      self.index[a][v].append(dn)
+	    except KeyError:
+    	      self.index[a][v] = [ dn ]
+
+
 class FileWriter(AsyncSearchHandler):
   """
   Class for writing a stream of LDAP search results to a file object
