@@ -1,10 +1,9 @@
 """
 functions.py - wraps functions of module _ldap
-written by Michael Stroeder <michael@stroeder.com>
 
-See http://python-ldap.sourceforge.net for details.
+See http://www.python-ldap.org/ for details.
 
-\$Id: functions.py,v 1.18 2004/01/29 23:12:08 stroeder Exp $
+\$Id: functions.py,v 1.22 2009/04/17 14:34:34 stroeder Exp $
 
 Compability:
 - Tested with Python 2.0+ but should work with Python 1.5.x
@@ -19,18 +18,20 @@ Basically calls into the LDAP lib are serialized by the module-wide
 lock _ldapmodule_lock.
 """
 
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 __all__ = [
   'open','initialize','init',
   'explode_dn','explode_rdn',
-  'get_option','set_option'
+  'get_option','set_option',
 ]
 
 import sys,_ldap
 
 from ldap import _ldap_module_lock,LDAPError
 
+from ldap.dn import explode_dn,explode_rdn
+
 from ldap.ldapobject import LDAPObject
 
 if __debug__:
@@ -106,29 +107,6 @@ def open(host,port=389,trace_level=0,trace_file=sys.stdout,trace_stack_limit=Non
 init = open
 
 
-def explode_dn(dn,notypes=0):
-  """
-  explode_dn(dn [, notypes=0]) -> list
-  
-  This function takes a DN and breaks it up into its component parts.
-  The notypes parameter is used to specify that only the component's
-  attribute values be returned and not the attribute types.
-  """
-  return _ldap_function_call(_ldap.explode_dn,dn,notypes)
-
-
-def explode_rdn(rdn,notypes=0):
-  """
-  explode_rdn(rdn [, notypes=0]) -> list
-  
-  This function takes a RDN and breaks it up into its component parts
-  if it is a multi-valued RDN.
-  The notypes parameter is used to specify that only the component's
-  attribute values be returned and not the attribute types.
-  """
-  return _ldap_function_call(_ldap.explode_rdn,rdn,notypes)
-
-
 def get_option(option):
   """
   get_option(name) -> value
