@@ -1,5 +1,5 @@
-/* See http://python-ldap.sourceforge.net for details.
- * $Id: LDAPObject.c,v 1.79 2008/03/20 12:24:56 stroeder Exp $ */
+/* See http://www.python-ldap.org/ for details.
+ * $Id: LDAPObject.c,v 1.82 2009/04/17 12:19:09 stroeder Exp $ */
 
 #include "common.h"
 #include "patchlevel.h"
@@ -611,8 +611,8 @@ int py_ldap_sasl_interaction(   LDAP *ld,
 				void *in )
 {
   /* These are just typecasts */
-  sasl_interact_t *interact = in;
-  PyObject *SASLObject = defaults;
+  sasl_interact_t *interact = (sasl_interact_t *) in;
+  PyObject *SASLObject = (PyObject *) defaults;
   /* Loop over the array of sasl_interact_t structs */
   while( interact->id != SASL_CB_LIST_END ) {
     int rc = 0;
@@ -683,8 +683,8 @@ l_ldap_sasl_interactive_bind_s( LDAPObject* self, PyObject* args )
     msgid = ldap_sasl_interactive_bind_s(self->ldap, 
 					 who, 
 					 c_mechanism, 
-					 server_ldcs, 
-					 client_ldcs,
+					 (LDAPControl**) server_ldcs, 
+					 (LDAPControl**) client_ldcs,
 					 sasl_flags, 
 					 py_ldap_sasl_interaction, 
 					 SASLObject);
