@@ -1,5 +1,5 @@
-/* See http://python-ldap.sourceforge.net for details.
- * $Id: ldapcontrol.c,v 1.9 2008/03/20 12:24:56 stroeder Exp $ */
+/* See http://www.python-ldap.org/ for details.
+ * $Id: ldapcontrol.c,v 1.13 2009/04/17 12:19:09 stroeder Exp $ */
 
 #include "common.h"
 #include "LDAPObject.h"
@@ -241,13 +241,15 @@ encode_rfc2696(PyObject *self, PyObject *args)
     PyObject *res = 0;
     BerElement *ber = 0;
     struct berval cookie, *ctrl_val;
+    Py_ssize_t cookie_len;
     unsigned long size;
     ber_tag_t tag;
 
     if (!PyArg_ParseTuple(args, "is#:encode_page_control", &size,
-                          &cookie.bv_val, &cookie.bv_len)) {
+                          &cookie.bv_val, &cookie_len)) {
         goto endlbl;
     }
+    cookie.bv_len = (ber_len_t) cookie_len;
 
     if (!(ber = ber_alloc_t(LBER_USE_DER))) {
         LDAPerr(LDAP_NO_MEMORY);
@@ -298,11 +300,13 @@ decode_rfc2696(PyObject *self, PyObject *args)
     ber_tag_t tag;
     struct berval *cookiep;
     unsigned long count;
+    Py_ssize_t ldctl_value_len;
 
     if (!PyArg_ParseTuple(args, "s#:decode_page_control",
-                          &ldctl_value.bv_val, &ldctl_value.bv_len)) {
+                          &ldctl_value.bv_val, &ldctl_value_len)) {
         goto endlbl;
     }
+    ldctl_value.bv_len = (ber_len_t) ldctl_value_len;
 
     if (!(ber = ber_init(&ldctl_value))) {
         LDAPerr(LDAP_NO_MEMORY);
@@ -323,11 +327,40 @@ decode_rfc2696(PyObject *self, PyObject *args)
     return res;
 }
 
+#ifdef LIBLDAP_HAS_ASSERTION_CONTROL_FUNC
+static PyObject*
+encode_assertion_control(PyObject *self, PyObject *args)
+{
+    int err;
+    PyObject *res = 0;
+    char *assertion_filterstr;
+    struct berval ctrl_val;
+    BerElement *ber = 0;
+
+    if (!PyArg_ParseTuple(args, "s:encode_assertion_control",
+                          &assertion_filterstr)) {
+        goto endlbl;
+    }
+
+    err = ldap_create_assertion_control_value(NULL,assertion_filterstr,&ctrl_val);
+
+    res = Py_BuildValue("s#", ctrl_val.bv_val, ctrl_val.bv_len);
+
+    endlbl:
+       if (ber)
+           ber_free(ber, 1);
+
+    return res;
+}
+#endif
 
 static PyMethodDef methods[] = {
     {"encode_page_control", encode_rfc2696, METH_VARARGS },
     {"decode_page_control", decode_rfc2696, METH_VARARGS },
     {"encode_valuesreturnfilter_control", encode_rfc3876, METH_VARARGS },
+#ifdef LIBLDAP_HAS_ASSERTION_CONTROL_FUNC
+    {"encode_assertion_control", encode_assertion_control, METH_VARARGS },
+#endif
     { NULL, NULL }
 };
 
