@@ -1,5 +1,5 @@
-/* See http://python-ldap.sourceforge.net for details.
- * $Id: options.c,v 1.18 2008/03/29 11:44:41 stroeder Exp $ */
+/* See http://www.python-ldap.org/ for details.
+ * $Id: options.c,v 1.21 2009/04/17 12:19:09 stroeder Exp $ */
 
 #include "common.h"
 #include "errors.h"
@@ -105,7 +105,7 @@ LDAP_set_option(LDAPObject *self, int option, PyObject *value)
     if (self) LDAP_END_ALLOW_THREADS(self);
 
     if ((option == LDAP_OPT_SERVER_CONTROLS) || (option == LDAP_OPT_CLIENT_CONTROLS))
-        LDAPControl_List_DEL(ptr);
+        LDAPControl_List_DEL((LDAPControl**) ptr);
     
     if (res != LDAP_OPT_SUCCESS) {
 	LDAPerr(res);
@@ -205,6 +205,10 @@ LDAP_get_option(LDAPObject *self, int option)
     case LDAP_OPT_X_TLS_RANDOM_FILE:
 #ifdef HAVE_SASL
     case LDAP_OPT_X_SASL_SECPROPS:
+    case LDAP_OPT_X_SASL_MECH:
+    case LDAP_OPT_X_SASL_REALM:
+    case LDAP_OPT_X_SASL_AUTHCID:
+    case LDAP_OPT_X_SASL_AUTHZID:
 #endif
 	    /* String-valued options */
 	    if (self) LDAP_BEGIN_ALLOW_THREADS(self);
